var audioHandler = (function () {
	var audioElement = document.createElement('audio');
	audioElement.loop = true;
	audioElement.volume = 1;
	var layers = [];
	var layersCache = [];
	var synchDate = new Date();
	var synchTimeout = null;
	var audioToSynch = [];
	
	var audioExists = function(index){
		var i = 0;
		for(i = 0; i< layersCache.length; i++){
			if(layersCache[i].id === index){
				return layersCache[i].audio;
			}
		}
		return null;
	};
	
	
	return {
		init : function(initSound){
			synchTimeout = null;
			audioToSynch = [];
			
			if(initSound){
				audioElement.setAttribute('src', audio[initSound]);
				audioElement.play();
			}
			
			for(var i =0; i < layers.length; i++){
				layers[i].pause();
			}
			layers = [];
		},
		addLayer: function(stack){
			var index = stack.index;
			var type = stack.type;
			
			var createAudio = function(index){
				var newAudio = document.createElement('audio');
				newAudio.loop = true;
				newAudio.setAttribute('src', audio[index]);
				return newAudio;
			};
			var _audio =audioExists(index); 
			if(_audio === null){
				_audio = createAudio(index);
				layersCache.push({id:index,audio:_audio});
			}
				
			
			if(type === "synch" && audioToSynch.length > 0) {
				if(synchTimeout != null) {window.clearTimeout(synchTimeout);}
				var currentDate = new Date;
				var diff = currentDate - synchDate;
				var delta = diff % stack.delay;
				audioToSynch.push(_audio);
				// synch in delta
				synchTimeout = window.setTimeout(function(){
					for(var i =0; i < audioToSynch.length; i++){
						audioToSynch[i].pause();
						audioToSynch[i].currentTime=0;
					}
					for(var i =0; i < audioToSynch.length; i++){
					audioToSynch[i].play();
					}
					synchDate = new Date();
				},delta);
			} else if(type == "stack"){
				_audio.play();
			}
			
			// First layer will be synch;
			if(layers.length === 0){
				audioToSynch.push(_audio);
				synchDate = new Date();
			}
			layers.push(_audio);
		},
		
		playLoop: function(index){
			if(audioElement.getAttribute("src")){
				try {
					audioElement.currentTime=0;
				} catch(err) {
					console.log("set currentTime was not needed");
				}
				audioElement.pause();
			}
			audioElement.setAttribute('src', audio[index]);
			audioElement.loop = true;
			audioElement.play();
		},
		playOnce: function(index){
			if(audioElement.getAttribute("src")){
				try {
					audioElement.currentTime=0;
				} catch(err) {
					console.log("set currentTime was not needed");
				}
				audioElement.pause();
			}
			audioElement.loop = false;
			audioElement.setAttribute('src', audio[index]);
			audioElement.play();
		},
		stop : function(){
			audioElement.currentTime=0;
			audioElement.pause();
		}
	};
})();